######################################################################
## Function for reading the Cards corpus in to R as a data frame.
##
##  author: Christopher Potts
##    date: 2012-03-03
## credits: Thanks to Karl Schultz for designing the data collecting program, and
##          to David Clausen, Alex Djalali, Sven Lauer, Victoria Schwanda, Chriz Czyzewicz,
##          and the rest of the SUBTLE team for their help with data collection. 
##          This research was supported in part by ONR grant No. N00014-10-1-0109 and 
##          ARO grant No. W911NF-07-1-0216.
## license: Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License:
##          http://creativecommons.org/licenses/by-nc-sa/3.0/
## version: 2.0
## maintainer: Christopher Potts
## email: See the author's website

######################################################################
## Read all the corpus transcripts into a single data frame.  Each one
## that is read in has its filename added to all its rows for easy
## by-row identification and chunking.  The return value is a
## data.frame.
ReadCardsCorpus = function(dirname){
  ## Get all the filenames into a vector:
  filenames = Sys.glob(file.path(dirname, '*/*.csv'))
  ## Read in the first to establish the basic structure:
  cards = read.csv(filenames[1], header=FALSE)
  ## Add the filename as a transcript identifier:
  cards$transcript = basename(filenames[1])
  ## Iterate through all the remaning files, adding them to the cards df:
  for (i in 2:length(filenames)){
    trans = read.csv(filenames[i], header=FALSE)
    trans$transcript = basename(filenames[i])    
    cards = rbind(cards, trans)    
  }
  ## Column names:
  colnames(cards) = c('agent', 'time', 'action', 'contents', 'transcript')
  ## Return the data frame:
  return(cards)
}

## Example usage if you're in the same directory as the transcripts:
## dirname = 'transcripts'
## cards = ReadCardsCorpus(dirname) ## This step can take a while!
## Now check out the first few lines:
## head(cards)
